@@ -4,7 +4,7 @@ from datetime import datetime
 from enum import IntEnum
 from io import StringIO
 from os import path, makedirs
-from sys import stdout, stderr
+from sys import stdout, stderr, exc_info
 from typing import *
 import traceback
 import typing
@@ -94,6 +94,6 @@ class Logger:
         if ex:
             traceback.print_exception(type(ex), ex, ex.__traceback__, file=strbuff)
         else:
-            traceback.print_exception(*sys.exc_info(), file=strbuff)
+            traceback.print_exception(*exc_info(), file=strbuff)
         strbuff.seek(0)
         return self.e(strbuff.read(), file=file)
